# Author: Emma Chalençon
# Creation date: 29/07/2020
# Python version 3.8.2

# Importing the needed packages:

import netCDF4
import numpy as np
import gdal
from scipy.interpolate import griddata
from global_land_mask import globe
from osgeo import osr
from osgeo import ogr

# Setting the inputs :

directory='C:/Gridded_files/' #the user should change the path to his/her .nc files' directory
filename='YYYY_MM.nc' #the user should change to the file of his/her interest
S = netCDF4.Dataset(directory+filename)
lon = S.variables['lon'][:]
lat = S.variables['lat'][:]
ssh = S.variables['ssh'][:] 
min_lat=53.0
max_lat=66.0
min_lon=9.0
max_lon=31.0

# Creating the array :

grid_size=0.1 #the user should change the size to the pixel size of his/her interest
grid_y, grid_x = np.mgrid[max_lat:min_lat:-grid_size,min_lon:max_lon:grid_size]
points=np.column_stack((lon,lat))
grid_z0 = griddata(points, ssh, (grid_x, grid_y), method='linear')

print ("The array is created")

# Masking the land :

for i in np.arange(0,np.shape(grid_x)[0]) : 
   for j in np.arange(0,np.shape(grid_x)[1]) : 
       if globe.is_land( grid_y[i,j],grid_x[i,j]) : 
           grid_z0[i,j] = np.nan

print("Land is masked")

# Creating the raster:

rasterName = directory + filename[0:- 3]+ ".tif"

ncols, nrows = np.shape(grid_z0)
geotransform=(min_lon,grid_size,0,min_lat,0,grid_size)
driver = gdal.GetDriverByName('GTiff')
outputRaster= driver.Create(rasterName,nrows,ncols,1,gdal.GDT_Float64)

outputRaster.SetGeoTransform(geotransform)
grid_z0 = np.flipud(grid_z0)

outband = outputRaster.GetRasterBand(1)
outband.WriteArray(grid_z0)

srs = osr.SpatialReference()                 
srs.ImportFromEPSG(4326)                     
outputRaster.SetProjection(srs.ExportToWkt())   
outputRaster.FlushCache()
outputRaster = None

print("The raster file is created")
