# Author: Emma Chalençon
# Creation date: 30/07/2020
# Python version 3.8.2

# Importing the needed packages:

import os
import netCDF4
import gdal
import numpy as np
import csv
from osgeo import osr
import osgeo.ogr, osgeo.osr 
from osgeo import ogr


# Setting the inputs :

directory='C:/Alongtrack_files/' #the user should change the path to his/her .nc files' directory
filename='jason1_em_hf_262_0014.nc' #the user should change to the file of his/her interest
output_directory='C:/Alongtrack_shp/' #the user should change the path to his/her output directory
S = netCDF4.Dataset(directory+filename)
lon = S.variables['lon'][:]
lat = S.variables['lat'][:]
ssh = S.variables['ssh'][:] 

#Creation of the dictionary

to_be_written = {}
for i in range (len(lat)):
    key = i
    if np.isnan(ssh[i]):
        to_be_written[key] =[lat[i], lon[i], 99999.999999999999999]
    else:
        to_be_written[key] =[lat[i], lon[i], ssh[i]]


print ("Dictionary written")

#Dictionary written in a csv file   

csv_file = open((output_directory+filename[0:-3])+ ".csv", "w")
headers =["ID", "ssh", "lat", "lon"]
writer = csv.DictWriter(csv_file, fieldnames= headers)
writer.writeheader()
for key, value in to_be_written.items():
    writer.writerow({'ID' : key, 'ssh': value [2], "lat": value[0], "lon": value[1]})
csv_file.close()

print ("CSV file created")

#Create shapefile

csvfile = (output_directory + filename[0:-3]) + ".csv"
shpfile = (output_directory + filename[0:-3]) + ".shp"

spatialReference = osgeo.osr.SpatialReference() 
spatialReference.ImportFromEPSG(int(4326)) #the user should change the EPSG to the EPSG of his/her interest
S = netCDF4.Dataset(directory+filename)
driver = osgeo.ogr.GetDriverByName('ESRI Shapefile') 
shapeData = driver.CreateDataSource(shpfile) 
layer = shapeData.CreateLayer('layer', spatialReference, osgeo.ogr.wkbPoint) 
layer_defn = layer.GetLayerDefn() 
index = 0


with open(csvfile, 'r') as csvfile:
    readerDict = csv.DictReader(csvfile, delimiter=',')
    for field in readerDict.fieldnames:
        new_field = ogr.FieldDefn(field, ogr.OFTString) 
        layer.CreateField(new_field)
    for row in readerDict:
        point = osgeo.ogr.Geometry(osgeo.ogr.wkbPoint)
        point.AddPoint(float(row['lon']), float(row['lat'])) 
        feature = osgeo.ogr.Feature(layer_defn)
        feature.SetGeometry(point) 
        feature.SetFID(index)
        for field in readerDict.fieldnames:
            i = feature.GetFieldIndex(field)
            feature.SetField(i, row[field])
        layer.CreateFeature(feature)
        index += 1
shapeData.Destroy()

print ("SHP file created")
