# Author: Emma Chalençon, Marcello Passaro
# Creation date: 25/06/2020
# Python version 3.8.2

# Importing the needed packages:

import netCDF4
import numpy as np
import cartopy as cart
from cartopy.mpl.ticker import LongitudeFormatter, LatitudeFormatter
import matplotlib.pyplot as plt
import cartopy.crs as ccrs
from scipy.interpolate import griddata
from global_land_mask import globe

# Setting the inputs :

directory='C:/some-dir' #the user should change the path to his/her .nc files' directory
filename='2002_06.nc' #the user should change to the file of his/her interest 
S = netCDF4.Dataset(directory+filename)
lon = S.variables['lon'][:]
lat = S.variables['lat'][:]
ssh = S.variables['ssh'][:] 
min_lat=53.0
max_lat=66.0
min_lon=9.0
max_lon=31.0

# This sets outlines the key elements of the structured grid.
grid_size = 0.1
grid_x, grid_y = np.mgrid[max_lat:min_lat:-grid_size,min_lon:max_lon:grid_size]
points = np.column_stack((lon, lat))
grid_z0 = griddata(points, ssh, (grid_y, grid_x), method='linear')

# Displaying an interpolated Baltic SEAL product onto a structured grid: 
 
fig = plt.plot() 
plt.rcParams.update({'font.size': 15}) 
plt.plot 
plt.rcParams["figure.figsize"] = (50, 10) #Increase figure size
ax = plt.axes(projection=ccrs.Miller())
for i in np.arange(0,np.shape(grid_y)[0]):
   for j in np.arange(0,np.shape(grid_y)[1]):
       if globe.is_land( grid_x[i, j], grid_y[i, j]):
           grid_z0[i, j] = np.nan
img=plt.pcolormesh(grid_y, grid_x, grid_z0,
          cmap='cool', alpha=1,transform=ccrs.PlateCarree())  
ax.coastlines(resolution='10m', color='black', linewidth=1)  
ax.set_xticks(np.arange(min_lon,max_lon,2), crs=ccrs.PlateCarree()) 
ax.set_yticks(np.arange(min_lat,max_lat,1), crs=ccrs.PlateCarree()) 
lon_formatter = cart.mpl.ticker.LongitudeFormatter(number_format='.1f',  
                                  degree_symbol='',  
                                  dateline_direction_label=True) 
lat_formatter = cart.mpl.ticker.LatitudeFormatter(number_format='.1f',  
                                 degree_symbol='') 
ax.xaxis.set_major_formatter(lon_formatter) 
ax.yaxis.set_major_formatter(lat_formatter)  
plt.colorbar(img,label=r'SSH (m)') 
plt.show()#A window will show up, allowing the user to see and download the plot 
